@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2009, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,8 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: SeleniumTestCase.php 5307 2009-11-06 08:15:44Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -60,9 +59,9 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.5
+ * @version    Release: 3.4.13
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -217,6 +216,19 @@ abstract class PHPUnit_Extensions_SeleniumTestCase extends PHPUnit_Framework_Tes
                             $browserSuite->addTest($dataSuite);
                         }
 
+                        // Test method with invalid @dataProvider.
+                        else if ($data === FALSE) {
+                            $browserSuite->addTest(
+                              new PHPUnit_Framework_Warning(
+                                sprintf(
+                                  'The data provider specified for %s::%s is invalid.',
+                                  $className,
+                                  $name
+                                )
+                              )
+                            );
+                        }
+
                         // Test method without @dataProvider.
                         else {
                             $browserSuite->addTest(
@@ -254,6 +266,19 @@ abstract class PHPUnit_Extensions_SeleniumTestCase extends PHPUnit_Framework_Tes
                         $suite->addTest($dataSuite);
                     }
 
+                    // Test method with invalid @dataProvider.
+                    else if ($data === FALSE) {
+                        $suite->addTest(
+                          new PHPUnit_Framework_Warning(
+                            sprintf(
+                              'The data provider specified for %s::%s is invalid.',
+                              $className,
+                              $name
+                            )
+                          )
+                        );
+                    }
+
                     // Test method without @dataProvider.
                     else {
                         $suite->addTest(
