@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2009, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,8 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Fileloader.php 5439 2009-12-14 22:12:15Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.3.0
  */
@@ -57,7 +56,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @version    Release: @package_version@
  * @link       http://www.phpunit.de/
@@ -81,7 +80,9 @@ class PHPUnit_Util_Fileloader
         }
 
         if (!is_readable($filename)) {
-            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'existing file');
+            throw new RuntimeException(
+              sprintf('Cannot open file "%s".' . "\n", $filename)
+            );
         }
 
         if ($syntaxCheck) {
@@ -100,19 +101,11 @@ class PHPUnit_Util_Fileloader
      */
     public static function load($filename)
     {
-        $_filename = PHPUnit_Util_Filesystem::fileExistsInIncludePath(
+        $filename = PHPUnit_Util_Filesystem::fileExistsInIncludePath(
           $filename
         );
 
-        if (!$_filename) {
-            throw new RuntimeException(
-              sprintf('Cannot open file "%s".' . "\n", $filename)
-            );
-        }
-
-        $filename         = $_filename;
         $oldVariableNames = array_keys(get_defined_vars());
-        unset($_filename);
 
         include_once $filename;
 
