@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2009, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,8 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Getopt.php 5230 2009-09-13 14:31:10Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -55,12 +54,11 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @package    PHPUnit
  * @author     Andrei Zmievski <andrei@php.net>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.5
+ * @version    Release: 3.4.13
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
- * @abstract
  */
 class PHPUnit_Util_Getopt
 {
@@ -77,25 +75,30 @@ class PHPUnit_Util_Getopt
             sort($long_options);
         }
 
-        if (isset($args[0]{0}) && $args[0]{0} != '-') {
+        if (isset($args[0][0]) && $args[0][0] != '-') {
             array_shift($args);
         }
 
         reset($args);
+        array_map('trim', $args);
 
         while (list($i, $arg) = each($args)) {
+            if ($arg == '') {
+                continue;
+            }
+
             if ($arg == '--') {
                 $non_opts = array_merge($non_opts, array_slice($args, $i + 1));
                 break;
             }
 
-            if ($arg{0} != '-' ||
-                (strlen($arg) > 1 && $arg{1} == '-' && !$long_options)) {
+            if ($arg[0] != '-' ||
+                (strlen($arg) > 1 && $arg[1] == '-' && !$long_options)) {
                 $non_opts = array_merge($non_opts, array_slice($args, $i));
                 break;
             }
 
-            elseif (strlen($arg) > 1 && $arg{1} == '-') {
+            elseif (strlen($arg) > 1 && $arg[1] == '-') {
                 self::parseLongOption(
                   substr($arg, 2), $long_options, $opts, $args
                 );
@@ -116,18 +119,18 @@ class PHPUnit_Util_Getopt
         $argLen = strlen($arg);
 
         for ($i = 0; $i < $argLen; $i++) {
-            $opt     = $arg{$i};
+            $opt     = $arg[$i];
             $opt_arg = NULL;
 
             if (($spec = strstr($short_options, $opt)) === FALSE ||
-                $arg{$i} == ':') {
+                $arg[$i] == ':') {
                 throw new PHPUnit_Framework_Exception(
                   "unrecognized option -- $opt"
                 );
             }
 
-            if (strlen($spec) > 1 && $spec{1} == ':') {
-                if (strlen($spec) > 2 && $spec{2} == ':') {
+            if (strlen($spec) > 1 && $spec[1] == ':') {
+                if (strlen($spec) > 2 && $spec[2] == ':') {
                     if ($i + 1 < $argLen) {
                         $opts[] = array($opt, substr($arg, $i + 1));
                         break;
@@ -155,11 +158,18 @@ class PHPUnit_Util_Getopt
 
     protected static function parseLongOption($arg, $long_options, &$opts, &$args)
     {
-        @list($opt, $opt_arg) = explode('=', $arg);
-        $opt_len              = strlen($opt);
-        $count_long_options   = count($long_options);
+        $count   = count($long_options);
+        $list    = explode('=', $arg);
+        $opt     = $list[0];
+        $opt_arg = NULL;
 
-        for ($i = 0; $i < $count_long_options; $i++) {
+        if (count($list) > 1) {
+            $opt_arg = $list[1];
+        }
+
+        $opt_len = strlen($opt);
+
+        for ($i = 0; $i < $count; $i++) {
             $long_opt  = $long_options[$i];
             $opt_start = substr($long_opt, 0, $opt_len);
 
@@ -169,8 +179,7 @@ class PHPUnit_Util_Getopt
 
             $opt_rest = substr($long_opt, $opt_len);
 
-            if ($opt_rest != '' && $opt{0} != '=' &&
-                $i + 1 < $count_long_options &&
+            if ($opt_rest != '' && $opt[0] != '=' && $i + 1 < $count &&
                 $opt == substr($long_options[$i+1], 0, $opt_len)) {
                 throw new PHPUnit_Framework_Exception(
                   "option --$opt is ambiguous"
