@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2009, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,8 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: CPD.php 4404 2008-12-31 09:27:18Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.2.0
  */
@@ -59,9 +58,9 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.13
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.2.0
  */
@@ -109,19 +108,15 @@ class PHPUnit_Util_Log_CPD extends PHPUnit_Util_Printer
             $xmlDuplication->appendChild(
               $document->createElement(
                 'codefragment',
-                htmlspecialchars(
-                  PHPUnit_Util_XML::convertToUtf8(
-                    join(
-                      '',
-                      array_slice(
-                        $duplicate['fileA']->getLines(),
-                        $duplicate['firstLineA'] - 1,
-                        $duplicate['numLines']
-                      )
+                PHPUnit_Util_XML::prepareString(
+                  join(
+                    '',
+                    array_slice(
+                      $duplicate['fileA']->getLines(),
+                      $duplicate['firstLineA'] - 1,
+                      $duplicate['numLines']
                     )
-                  ),
-                  ENT_COMPAT,
-                  'UTF-8'
+                  )
                 )
               )
             );
