@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2009, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2010, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,8 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Source.php 4707 2009-03-08 14:44:17Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.3.0
  */
@@ -60,9 +59,9 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.5
+ * @version    Release: 3.4.13
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.3.0
  */
@@ -145,12 +144,7 @@ class PHPUnit_Util_Log_CodeCoverage_XML_Source
 
                     $xmlLine->appendChild(
                       $document->createElement(
-                        'body',
-                        htmlspecialchars(
-                          PHPUnit_Util_XML::convertToUtf8($line),
-                          ENT_COMPAT,
-                          'UTF-8'
-                        )
+                        'body', PHPUnit_Util_XML::prepareString($line)
                       )
                     );
 
@@ -171,10 +165,8 @@ class PHPUnit_Util_Log_CodeCoverage_XML_Source
                                     $xmlTest->appendChild(
                                       $document->createElement(
                                         'message',
-                                        htmlspecialchars(
-                                          PHPUnit_Util_XML::convertToUtf8($test->getStatusMessage()),
-                                          ENT_COMPAT,
-                                          'UTF-8'
+                                        PHPUnit_Util_XML::prepareString(
+                                          $test->getStatusMessage()
                                         )
                                       )
                                     );
@@ -253,12 +245,7 @@ class PHPUnit_Util_Log_CodeCoverage_XML_Source
 
                     $xmlLine->appendChild(
                       $document->createElement(
-                        'body',
-                        htmlspecialchars(
-                          PHPUnit_Util_XML::convertToUtf8($line),
-                          ENT_COMPAT,
-                          'UTF-8'
-                        )
+                        'body', PHPUnit_Util_XML::prepareString($line)
                       )
                     );
 
